@@ -1,6 +1,9 @@
 """
 dlg_lowpass_components filters
 """
+import pickle
+
+from .utils import PRECISIONS
 import logging
 
 import numpy as np
@@ -54,22 +57,16 @@ class LPFilterFFTNP(BarrierAppDROP):
         [dlg_streaming_input("binary/*")],
     )
 
-    PRECISIONS = {
-        "double": {"float": np.float64, "complex": np.complex128},
-        "single": {"float": np.float32, "complex": np.complex64},
-    }
     precision = {}
     # default values
     doubleprecision = dlg_bool_param("doubleprecision", True)
-    series = []
-    output = np.zeros([1])
 
     def initialize(self, **kwargs):
         super().initialize(**kwargs)
         if self.doubleprecision:
-            self.precision = self.PRECISIONS["double"]
+            self.precision = PRECISIONS["double"]
         else:
-            self.precision = self.PRECISIONS["single"]
+            self.precision = PRECISIONS["single"]
 
     def get_inputs(self):
         """
@@ -80,21 +77,21 @@ class LPFilterFFTNP(BarrierAppDROP):
         if len(ins) != 2:
             raise Exception("Precisely two input required for %r" % self)
 
-        array = [np.frombuffer(droputils.allDropContents(inp)) for inp in ins]
-        self.series = array
+        array = [pickle.loads(droputils.allDropContents(inp)) for inp in ins]
+        return array
 
-    def filter(self):
+    def filter(self, signal, window):
         """
         Actually performs the filtering
+        :param:signal The input signal to be filtered
+        :param:window The window used as the lowpass filter
         :return: Numpy array of filtered signal.
         """
-        signal = self.series[0]
-        window = self.series[1]
         nfft = determine_size(len(signal) + len(window) - 1)
         sig_zero_pad = np.zeros(nfft, dtype=self.precision["float"])
         win_zero_pad = np.zeros(nfft, dtype=self.precision["float"])
-        sig_zero_pad[0 : len(signal)] = signal
-        win_zero_pad[0 : len(window)] = window
+        sig_zero_pad[0: len(signal)] = signal
+        win_zero_pad[0: len(window)] = window
         sig_fft = np.fft.fft(sig_zero_pad)
         win_fft = np.fft.fft(win_zero_pad)
         out_fft = np.multiply(sig_fft, win_fft)
@@ -109,9 +106,9 @@ class LPFilterFFTNP(BarrierAppDROP):
         outs = self.outputs
         if len(outs) < 1:
             raise Exception("At least one output required for %r" % self)
-        self.get_inputs()
-        self.output = self.filter()
-        data = self.output.tobytes()
+        input_data = self.get_inputs()
+        output_data = self.filter(input_data[0], input_data[1])
+        data = pickle.dumps(output_data)
         for output in outs:
             output.len = len(data)
             output.write(data)
@@ -158,19 +155,19 @@ class LPFilterFFTFFTW(LPFilterFFTNP):
         [dlg_streaming_input("binary/*")],
     )
 
-    def filter(self):
+    def filter(self, signal, window):
         """
         Actually performs the filtering
+        :param:signal The input signal to be filtered
+        :param:window The window used as the lowpass filter
         :return: Filtered signal as numpy array.
         """
         pyfftw.interfaces.cache.disable()
-        signal = self.series[0]
-        window = self.series[1]
         nfft = determine_size(len(signal) + len(window) - 1)
         sig_zero_pad = pyfftw.empty_aligned(len(signal), dtype=self.precision["float"])
         win_zero_pad = pyfftw.empty_aligned(len(window), dtype=self.precision["float"])
-        sig_zero_pad[0 : len(signal)] = signal
-        win_zero_pad[0 : len(window)] = window
+        sig_zero_pad[0: len(signal)] = signal
+        win_zero_pad[0: len(window)] = window
         sig_fft = pyfftw.interfaces.numpy_fft.fft(sig_zero_pad, n=nfft)
         win_fft = pyfftw.interfaces.numpy_fft.fft(win_zero_pad, n=nfft)
         out_fft = np.multiply(sig_fft, win_fft)
@@ -211,9 +208,11 @@ class LPFilterFFTCuda(LPFilterFFTNP):
         [dlg_streaming_input("binary/*")],
     )
 
-    def filter(self):
+    def filter(self, signal, window):
         """
         Actually performs the filtering
+        :param:signal The input signal to be filtered
+        :param:window The window used as the lowpass filter
         :return:
         """
         import pycuda.gpuarray as gpuarray
@@ -225,8 +224,6 @@ class LPFilterFFTCuda(LPFilterFFTNP):
         cuda.init()
         context = make_default_context()
         device = context.get_device()
-        signal = self.series[0]
-        window = self.series[1]
         linalg.init()
         nfft = determine_size(len(signal) + len(window) - 1)
         # Move data to GPU
@@ -234,8 +231,8 @@ class LPFilterFFTCuda(LPFilterFFTNP):
         win_zero_pad = np.zeros(nfft, dtype=self.precision["float"])
         sig_gpu = gpuarray.zeros(sig_zero_pad.shape, dtype=self.precision["float"])
         win_gpu = gpuarray.zeros(win_zero_pad.shape, dtype=self.precision["float"])
-        sig_zero_pad[0 : len(signal)] = signal
-        win_zero_pad[0 : len(window)] = window
+        sig_zero_pad[0: len(signal)] = signal
+        win_zero_pad[0: len(window)] = window
         sig_gpu.set(sig_zero_pad)
         win_gpu.set(win_zero_pad)
 
@@ -300,7 +297,13 @@ class LPFilterPointwiseNP(LPFilterFFTNP):
         [dlg_streaming_input("binary/*")],
     )
 
-    def filter(self):
-        return np.convolve(self.series[0], self.series[1], mode="full").astype(
+    def filter(self, signal, window):
+        """
+        Actually performs the filtering
+        :param:signal The input signal to be filtered
+        :param:window The window used as the lowpass filter
+        :return:
+        """
+        return np.convolve(signal, window, mode="full").astype(
             self.precision["complex"]
         )
