@@ -1,6 +1,5 @@
+import pickle
 import unittest
-import time
-import numpy as np
 
 from dlg_lowpass_components import (
     LPSignalGenerator,
@@ -9,7 +8,7 @@ from dlg_lowpass_components import (
     LPFilterFFTFFTW,
     LPFilterFFTCuda,
     LPFilterPointwiseNP,
-    LPFilterFFTNP,
+    LPFilterFFTNP, LPCorrelate,
 )
 from dlg.drop import InMemoryDROP
 from dlg.droputils import allDropContents, DROPWaiterCtx
@@ -28,7 +27,7 @@ class TestLPSignalGenerator(unittest.TestCase):
         generator = LPSignalGenerator("a", "a")
         signal = _run_component(generator)
         self.assertIsNotNone(signal)
-        self.assertEqual(generator.length * 8, len(signal))
+        self.assertEqual(generator.length, len(pickle.loads(signal)))
 
     def test_changed_length(self):
         new_length = 1024
@@ -36,7 +35,7 @@ class TestLPSignalGenerator(unittest.TestCase):
         signal = _run_component(generator)
         self.assertIsNotNone(signal)
         self.assertEqual(new_length, generator.length)
-        self.assertEqual(new_length * 8, len(signal))
+        self.assertEqual(new_length, len(pickle.loads(signal)))
 
     def test_added_noise(self):
         noise_params = {"noise": 0.0, "stddiv": 1.0, "frequency": 666, "randomseed": 42}
@@ -65,7 +64,7 @@ class TestLPWindowGenerator(unittest.TestCase):
         generator = LPWindowGenerator("a", "a")
         signal = _run_component(generator)
         self.assertIsNotNone(signal)
-        self.assertEqual(generator.length * 8, len(signal))
+        self.assertEqual(generator.length, len(pickle.loads(signal)))
 
     def test_change_length(self):
         new_length = 512
@@ -73,7 +72,7 @@ class TestLPWindowGenerator(unittest.TestCase):
         signal = _run_component(generator)
         self.assertIsNotNone(signal)
         self.assertEqual(new_length, generator.length)
-        self.assertEqual(new_length * 8, len(signal))
+        self.assertEqual(new_length, len(pickle.loads(signal)))
 
     def test_change_cutoff(self):
         new_cutoff = 660
@@ -142,7 +141,7 @@ def _run_filter(obj, filter):
         window_drop.setCompleted()
 
     filtered_signal = allDropContents(filtered_signal_drop)
-    return filtered_signal, len(in_signal)
+    return filtered_signal, len(pickle.loads(in_signal))
 
 
 class TestLPFilterFFTNP(unittest.TestCase):
@@ -151,8 +150,8 @@ class TestLPFilterFFTNP(unittest.TestCase):
         filtered_signal, original_length = _run_filter(self, filter)
         self.assertIsNotNone(filtered_signal)
         self.assertEqual(
-            original_length / 8 * 2 - 1,
-            len(filtered_signal) / np.dtype(complex).itemsize,
+            original_length * 2 - 1,
+            len(pickle.loads(filtered_signal)),
         )
 
     def test_precision(self):
@@ -169,8 +168,8 @@ class TestLPFilterFFTFFTW(unittest.TestCase):
         filtered_signal, original_length = _run_filter(self, filter)
         self.assertIsNotNone(filtered_signal)
         self.assertEqual(
-            original_length / 8 * 2 - 1,
-            len(filtered_signal) / np.dtype(complex).itemsize,
+            original_length * 2 - 1,
+            len(pickle.loads(filtered_signal)),
         )
 
     def test_precision(self):
@@ -188,8 +187,8 @@ class TestLPFilterFFTCuda(unittest.TestCase):
         filtered_signal, original_length = _run_filter(self, filter)
         self.assertIsNotNone(filtered_signal)
         self.assertEqual(
-            original_length / 8 * 2 - 1,
-            len(filtered_signal) / np.dtype(complex).itemsize,
+            original_length * 2 - 1,
+            len(pickle.loads(filtered_signal)),
         )
 
     def test_precision(self):
@@ -206,8 +205,8 @@ class TestLPFilterPointwiseNP(unittest.TestCase):
         filtered_signal, original_length = _run_filter(self, filter)
         self.assertIsNotNone(filtered_signal)
         self.assertEqual(
-            original_length / 8 * 2 - 1,
-            len(filtered_signal) / np.dtype(complex).itemsize,
+            original_length * 2 - 1,
+            len(pickle.loads(filtered_signal)),
         )
 
     def test_precision(self):
@@ -216,3 +215,35 @@ class TestLPFilterPointwiseNP(unittest.TestCase):
         float_signal, _ = _run_filter(self, float_filter)
         double_signal, _ = _run_filter(self, double_filter)
         self.assertNotEqual(float_signal, double_signal)
+
+
+class TestCorrelation(unittest.TestCase):
+    def test_correlation(self):
+        correlate = LPCorrelate("e", "e")
+        generator = LPSignalGenerator("a", "a")
+        filter = LPFilterPointwiseNP("g", "g")
+        signal_drop = InMemoryDROP("b", "b")
+        window_drop = InMemoryDROP("c", "c")
+        ncc_drop = InMemoryDROP("f", "f")
+        in_signal = _run_component(generator)
+
+        generator = LPWindowGenerator("a", "a")
+        window = _run_component(generator)
+        filtered_signal_drop = InMemoryDROP("d", "d")
+        filter.addInput(signal_drop)
+        filter.addInput(window_drop)
+        filter.addOutput(filtered_signal_drop)
+        correlate.addInput(signal_drop)
+        correlate.addInput(filtered_signal_drop)
+        correlate.addOutput(ncc_drop)
+
+        with DROPWaiterCtx(self, ncc_drop, 10):
+            signal_drop.write(in_signal)
+            window_drop.write(window)
+            signal_drop.setCompleted()
+            window_drop.setCompleted()
+
+        ncc = allDropContents(ncc_drop)
+        ncc_val = pickle.loads(ncc)
+        self.assertIsNotNone(ncc)
+        self.assertIsNotNone(ncc_val)
